@@ -88,6 +88,26 @@ require('tap').test('basic', function (t) {
       rawSpec: '=v1.2.3'
     },
 
+    'foo@npm:bar': {
+      name: 'foo',
+      escapedName: 'foo',
+      type: 'alias',
+      saveSpec: null,
+      fetchSpec: null,
+      raw: 'foo@npm:bar',
+      rawSpec: 'npm:bar',
+      subSpec: {
+        registry: true,
+        name: 'bar',
+        escapedName: 'bar',
+        type: 'tag',
+        raw: 'bar',
+        rawSpec: '',
+        saveSpec: null,
+        fetchSpec: 'latest'
+      }
+    },
+
     'git+ssh://git@notgithub.com/user/foo#1.2.3': {
       name: null,
       escapedName: null,
@@ -220,6 +240,18 @@ require('tap').test('basic', function (t) {
       raw: 'git+ssh://git@notgithub.com/user/foo#semver:^1.2.3'
     },
 
+    'git+ssh://git@notgithub.com:user/foo#semver:^1.2.3': {
+      name: null,
+      escapedName: null,
+      type: 'git',
+      hosted: null,
+      saveSpec: 'git+ssh://git@notgithub.com:user/foo#semver:^1.2.3',
+      fetchSpec: 'git@notgithub.com:user/foo',
+      gitCommittish: null,
+      gitRange: '^1.2.3',
+      raw: 'git+ssh://git@notgithub.com:user/foo#semver:^1.2.3'
+    },
+
     'git+ssh://git@github.com/user/foo#semver:^1.2.3': {
       name: null,
       escapedName: null,
@@ -231,6 +263,17 @@ require('tap').test('basic', function (t) {
       raw: 'git+ssh://git@github.com/user/foo#semver:^1.2.3'
     },
 
+    'git+ssh://git@github.com:user/foo#semver:^1.2.3': {
+      name: null,
+      escapedName: null,
+      type: 'git',
+      saveSpec: 'git+ssh://git@github.com/user/foo.git#semver:^1.2.3',
+      fetchSpec: 'ssh://git@github.com/user/foo.git',
+      gitCommittish: null,
+      gitRange: '^1.2.3',
+      raw: 'git+ssh://git@github.com:user/foo#semver:^1.2.3'
+    },
+
     'user/foo#semver:^1.2.3': {
       name: null,
       escapedName: null,
@@ -383,6 +426,15 @@ require('tap').test('basic', function (t) {
       raw: 'file:////path/to/foo'
     },
 
+    'http://insecure.com/foo.tgz': {
+      name: null,
+      escapedName: null,
+      type: 'remote',
+      saveSpec: 'http://insecure.com/foo.tgz',
+      fetchSpec: 'http://insecure.com/foo.tgz',
+      raw: 'http://insecure.com/foo.tgz'
+    },
+
     'https://server.com/foo.tgz': {
       name: null,
       escapedName: null,
@@ -417,15 +469,28 @@ require('tap').test('basic', function (t) {
     Object.keys(tests[arg]).forEach(function (key) {
       t.has(res[key], tests[arg][key], arg + ' [' + key + ']')
     })
-//    t.has(res, tests[arg], arg + ' matches expectations')
+    //    t.has(res, tests[arg], arg + ' matches expectations')
   })
 
   var objSpec = {name: 'foo', rawSpec: '1.2.3'}
   t.equal(npa(objSpec, '/whatnot').toString(), 'foo@1.2.3', 'parsed object')
 
+  objSpec.where = '/whatnot'
+  t.equal(npa(objSpec).toString(), 'foo@1.2.3', 'parsed object w/o where arg')
+
+  t.equal(npa('git+http://foo.com/bar').toString(),
+    'git+http://foo.com/bar', 'parsed git toString')
+
   objSpec = {raw: './foo/bar', where: '/here'}
   t.equal(npa(objSpec).fetchSpec, '/here/foo/bar', '`where` is reused')
 
+  var res = new npa.Result({name: 'bar', rawSpec: './foo/bar'})
+  t.equal(res.toString(), 'bar@./foo/bar', 'toString with only rawSpec')
+  res = new npa.Result({rawSpec: './x/y'})
+  t.equal(res.toString(), './x/y', 'toString with only rawSpec, no name')
+  res = new npa.Result({rawSpec: ''})
+  t.equal(res.toString(), '', 'toString with nothing')
+
   objSpec = {raw: './foo/bar', where: '/here'}
   t.equal(npa(objSpec, '/whatnot').fetchSpec, '/whatnot/foo/bar', '`where` arg overrides the one in the spec object')
 
@@ -449,6 +514,14 @@ require('tap').test('basic', function (t) {
     npa.resolve('invalid/name', '1.0.0')
   }, 'Invalid names throw errrors')
 
+  t.throws(() => {
+    npa('foo@npm:bar@npm:baz')
+  }, 'nested aliases not supported')
+
+  t.throws(() => {
+    npa('foo@npm:foo/bar')
+  }, 'aliases only work for registry deps')
+
   t.has(npa.resolve('foo', '^1.2.3', '/test/a/b'), {type: 'range'}, 'npa.resolve')
   t.has(npa.resolve('foo', 'file:foo', '/test/a/b'), {type: 'directory', fetchSpec: '/test/a/b/foo'}, 'npa.resolve file:')
   t.has(npa.resolve('foo', '../foo/bar', '/test/a/b'), {type: 'directory'}, 'npa.resolve no protocol')
